Function del_func
pub unsafe fn del_func(ea: c_ulonglong) -> boolExpand description
Delete a function. \param ea any address in the function entry chunk \return success
pub unsafe fn del_func(ea: c_ulonglong) -> boolDelete a function. \param ea any address in the function entry chunk \return success